Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: client/crash_report_database.h

Issue 904533002: Add CrashReportDatabase::ErrorWritingCrashReport() (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | client/crash_report_database_mac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/crash_report_database.h
diff --git a/client/crash_report_database.h b/client/crash_report_database.h
index 3db2f583b978b4d32fc19c9394eabb805d2964d2..ef55d9d27be85cf1d154f7a2cadb5c975a3819d4 100644
--- a/client/crash_report_database.h
+++ b/client/crash_report_database.h
@@ -145,7 +145,7 @@ class CrashReportDatabase {
//!
//! Callers can then write the crash report using the file handle provided.
//! The caller does not own this handle, and it must be explicitly closed with
- //! FinishedWritingCrashReport().
+ //! FinishedWritingCrashReport() or ErrorWritingCrashReport().
//!
//! \param[out] report A file handle to which the crash report data should be
//! written. Only valid if this returns #kNoError. The caller must not
@@ -157,7 +157,7 @@ class CrashReportDatabase {
//! \brief Informs the database that a crash report has been written.
//!
//! After calling this method, the database is permitted to move and rename
//! the file at Report::file_path.
//!
//! \param[in] report A handle obtained with PrepareNewCrashReport(). The
//! handle will be invalidated as part of this call.
@@ -167,6 +167,19 @@ class CrashReportDatabase {
virtual OperationStatus FinishedWritingCrashReport(NewReport* report,
UUID* uuid) = 0;
+ //! \brief Informs the database that an error occurred while attempting to
+ //! write a crash report, and that any resources associated with it should
+ //! be cleaned up.
+ //!
+ //! After calling this method, the database is permitted to remove the file at
+ //! NewReport::path.
+ //!
+ //! \param[in] report A handle obtained with PrepareNewCrashReport(). The
+ //! handle will be invalidated as part of this call.
+ //!
+ //! \return The operation status code.
+ virtual OperationStatus ErrorWritingCrashReport(NewReport* report) = 0;
+
//! \brief Returns the crash report record for the unique identifier.
//!
//! \param[in] uuid The crash report record unique identifier.
@@ -157,7 +157,7 @@ class CrashReportDatabase {
//!
//! After calling this method, the database is permitted to move and rename
- //! the file at Report::file_path.
+ //! the file at NewReport::path.
//!
//! \param[in] report A handle obtained with PrepareNewCrashReport(). The
« no previous file with comments | « no previous file | client/crash_report_database_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698